@@ -7,6 +7,8 @@ module Gitlab
 
     # Please keep in alphabetical order
     include AccessRequests
+    include ApplicationSettings
+    include Avatar
     include AwardEmojis
     include Boards
     include Branches
@@ -14,15 +16,23 @@ module Gitlab
     include BuildVariables
     include Builds
     include Commits
+    include ContainerRegistry
     include Deployments
     include Environments
+    include Epics
     include Events
+    include Features
+    include GroupBoards
+    include GroupLabels
     include GroupMilestones
     include Groups
+    include IssueLinks
     include Issues
     include Jobs
     include Keys
     include Labels
+    include Lint
+    include Markdown
     include MergeRequestApprovals
     include MergeRequests
     include Milestones
@@ -32,12 +42,17 @@ module Gitlab
     include PipelineTriggers
     include Pipelines
     include ProjectBadges
+    include ProjectClusters
+    include ProjectReleaseLinks
+    include ProjectReleases
     include Projects
     include ProtectedTags
     include Repositories
     include RepositoryFiles
     include RepositorySubmodules
+    include ResourceLabelEvents
     include Runners
+    include Search
     include Services
     include Sidekiq
     include Snippets
@@ -58,8 +73,12 @@ module Gitlab
       inspected
     end
 
+    # Utility method for URL encoding of a string.
+    # Copied from https://ruby-doc.org/stdlib-2.7.0/libdoc/erb/rdoc/ERB/Util.html
+    #
+    # @return [String]
     def url_encode(url)
-      URI.encode(url.to_s, /\W/)
+      url.to_s.b.gsub(/[^a-zA-Z0-9_\-.~]/n) { |m| sprintf('%%%02X', m.unpack1('C')) } # rubocop:disable Style/FormatString, Style/FormatStringToken
     end
 
     private
