@@ -40,7 +40,7 @@ module Gitlab
       #
       # @return [String]
       def build_error_message
-        parsed_response = @response.parsed_response
+        parsed_response = classified_response
         message = check_error_keys(parsed_response)
         "Server responded with code #{@response.code}, message: " \
         "#{handle_message(message)}. " \
@@ -54,6 +54,17 @@ module Gitlab
         key ? resp.send(key) : resp
       end
 
+      # Parse the body based on the classification of the body content type
+      #
+      # @return parsed response
+      def classified_response
+        if @response.respond_to?('headers')
+          @response.headers['content-type'] == 'text/plain' ? { message: @response.to_s } : @response.parsed_response
+        else
+          @response.parsed_response
+        end
+      end
+
       # Handle error response message in case of nested hashes
       def handle_message(message)
         case message
@@ -84,12 +95,18 @@ module Gitlab
     # Raised when API endpoint returns the HTTP status code 405.
     class MethodNotAllowed < ResponseError; end
 
+    # Raised when API endpoint returns the HTTP status code 406.
+    class NotAcceptable < ResponseError; end
+
     # Raised when API endpoint returns the HTTP status code 409.
     class Conflict < ResponseError; end
 
     # Raised when API endpoint returns the HTTP status code 422.
     class Unprocessable < ResponseError; end
 
+    # Raised when API endpoint returns the HTTP status code 429.
+    class TooManyRequests < ResponseError; end
+
     # Raised when API endpoint returns the HTTP status code 500.
     class InternalServerError < ResponseError; end
 
@@ -98,5 +115,21 @@ module Gitlab
 
     # Raised when API endpoint returns the HTTP status code 503.
     class ServiceUnavailable < ResponseError; end
+
+    # HTTP status codes mapped to error classes.
+    STATUS_MAPPINGS = {
+      400 => BadRequest,
+      401 => Unauthorized,
+      403 => Forbidden,
+      404 => NotFound,
+      405 => MethodNotAllowed,
+      406 => NotAcceptable,
+      409 => Conflict,
+      422 => Unprocessable,
+      429 => TooManyRequests,
+      500 => InternalServerError,
+      502 => BadGateway,
+      503 => ServiceUnavailable
+    }.freeze
   end
 end
