@@ -50,6 +50,17 @@ describe Gitlab::Client do
     end
   end
 
+  describe '.merge_request_participants' do
+    before do
+      stub_get('/projects/3/merge_requests/1/participants', 'participants')
+      Gitlab.merge_request_participants(3, 1)
+    end
+
+    it 'gets the correct resource' do
+      expect(a_get('/projects/3/merge_requests/1/participants')).to have_been_made
+    end
+  end
+
   describe '.merge_request_pipelines' do
     before do
       stub_get('/projects/3/merge_requests/1/pipelines', 'pipelines')
